@@ -18,15 +18,15 @@ config etc/nail.rc.new
 ( cd usr/man/man1 ; ln -sf mailx.1.gz.gz nail.1.gz.gz )
 ( cd usr/man/man1 ; rm -rf Mail.1.gz.gz )
 ( cd usr/man/man1 ; ln -sf mailx.1.gz.gz Mail.1.gz.gz )
-( cd usr/bin ; rm -rf nail )
-( cd usr/bin ; ln -sf mailx nail )
-( cd usr/bin ; rm -rf mail )
-( cd usr/bin ; ln -sf mailx mail )
 ( cd usr/bin ; rm -rf Mail )
 ( cd usr/bin ; ln -sf mailx Mail )
-( cd bin ; rm -rf nail )
-( cd bin ; ln -sf ../usr/bin/mailx nail )
-( cd bin ; rm -rf mail )
-( cd bin ; ln -sf ../usr/bin/mailx mail )
+( cd usr/bin ; rm -rf mail )
+( cd usr/bin ; ln -sf mailx mail )
+( cd usr/bin ; rm -rf nail )
+( cd usr/bin ; ln -sf mailx nail )
 ( cd bin ; rm -rf Mail )
-( cd bin ; ln -sf ../usr/bin/mailx Mail )
+( cd bin ; ln -sf /usr/bin/mailx Mail )
+( cd bin ; rm -rf mail )
+( cd bin ; ln -sf /usr/bin/mailx mail )
+( cd bin ; rm -rf nail )
+( cd bin ; ln -sf /usr/bin/mailx nail )
